Method: Protocol::Redis::Methods::Strings#setrange
- Defined in:
- lib/protocol/redis/methods/strings.rb
#setrange(key, offset, value) ⇒ Object
Overwrite part of a string at key starting at the specified offset. O(1), not counting the time taken to copy the new string in place. Usually, this string is very small so the amortized complexity is O(1). Otherwise, complexity is O(M) with M being the length of the value argument. See <redis.io/commands/setrange> for more details.
188 189 190 |
# File 'lib/protocol/redis/methods/strings.rb', line 188 def setrange(key, offset, value) call("SETRANGE", key, offset, value) end |